==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/_ogre_billboard_particle_renderer_8h.js <==
var _ogre_billboard_particle_renderer_8h =
[
    [ "Ogre::v1::BillboardParticleRenderer::CmdAccurateFacing", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_accurate_facing.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_accurate_facing" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdBillboardOrigin", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_origin.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_origin" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdBillboardRotationType", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_rotation_type.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_rotation_type" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdBillboardType", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_type.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_type" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdCommonDirection", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_direction.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_direction" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdCommonUpVector", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_up_vector.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_up_vector" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdPointRendering", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_point_rendering.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_point_rendering" ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/_ogre_billboard_particle_renderer_8h.js <==
var _ogre_billboard_particle_renderer_8h =
[
    [ "Ogre::v1::BillboardParticleRenderer::CmdAccurateFacing", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_accurate_facing.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_accurate_facing" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdBillboardOrigin", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_origin.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_origin" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdBillboardRotationType", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_rotation_type.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_rotation_type" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdBillboardType", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_type.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_billboard_type" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdCommonDirection", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_direction.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_direction" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdCommonUpVector", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_up_vector.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_common_up_vector" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdPointRendering", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_point_rendering.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_point_rendering" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdTextureSlices", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_texture_slices.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_texture_slices" ],
    [ "Ogre::v1::BillboardParticleRenderer::CmdTextureStacks", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_texture_stacks.html", "class_ogre_1_1v1_1_1_billboard_particle_renderer_1_1_cmd_texture_stacks" ]
];
